==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Aggiungi proprietà personalizzata</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Valore:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Tipo:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <location filename="../PropertyEditor.js" line="+348"/>
        <source>Geometry</source>
        <translation>Geometria</translation>
    </message>
    <message>
        <location line="+277"/>
        <source>Add custom property to selected objects</source>
        <translation>Aggiungere una proprietà personalizzata per gli oggetti selezionati</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Sinistra</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Centro</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Destra</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Allineato</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Sopra</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Medio</translation>
    </message>
    <message>
        <location line="-435"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>*VARIA*</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: Arduino_it_IT.po--
Documento caricato:
Versione:</translatorcomment>
        <translation>:</translation>
    </message>
    <message>
        <location line="+137"/>
        <source>No Selection</source>
        <translatorcomment>--ignored case--
--file: photivo_it.ts--
Nessuna selezione</translatorcomment>
        <translation>Nessuna selezione</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Dependent Entities</source>
        <translation>Entità dipendenti</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
    <message>
        <location line="+135"/>
        <source>Index</source>
        <translation>Indice</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Rimuovere questa proprietà dagli oggetti selezionati</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>All</source>
        <translation>Tutto</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Aggiungi proprietà personalizzata</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--exact match--
--file: dia.master.it.po--
Adatta alla pagina
Primo punto di adattamento</translatorcomment>
        <translation type="obsolete">Fit</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">Sotto</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--exact match--
--file: src_shell_data_translations_ktoon_it.ts--
Disegna arco tangente alla base dell&apos;oggetto
Specifica la base</translatorcomment>
        <translation type="obsolete">Base</translation>
    </message>
    <message>
        <location line="+157"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location line="+119"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Utilizzare la misurazione automatica</translation>
    </message>
    <message>
        <location line="+32"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location line="+317"/>
        <location line="+12"/>
        <source>Property Editor</source>
        <translation>Editor delle proprietà</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: it3.po--</translatorcomment>
        <translation>Selezione:</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location line="+163"/>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Sposta la selezione ad un nuovo layer</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Handle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Maniglia:</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/PropertyEditor/ts/PropertyEditor_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>AddCustomPropertyDialog</name>
    <message>
        <location filename="../AddCustomPropertyDialog.ui" line="+14"/>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Aggiungi proprietà personalizzata</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Value:</source>
        <translation>Valore:</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation type="obsolete">Tipo:</translation>
    </message>
</context>
<context>
    <name>PropertyEditor</name>
    <message>
        <source>Geometry</source>
        <translation type="vanished">Geometria</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.js" line="+704"/>
        <source>Add custom property to selected objects</source>
        <translation>Aggiungere una proprietà personalizzata per gli oggetti selezionati</translation>
    </message>
    <message>
        <source>Left</source>
        <translation type="obsolete">Sinistra</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="obsolete">Centro</translation>
    </message>
    <message>
        <source>Right</source>
        <translation type="obsolete">Destra</translation>
    </message>
    <message>
        <source>Aligned</source>
        <translation type="obsolete">Allineato</translation>
    </message>
    <message>
        <source>Top</source>
        <translation type="obsolete">Sopra</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="obsolete">Medio</translation>
    </message>
    <message>
        <location line="+614"/>
        <source>*VARIES*</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>*VARIA*</translation>
    </message>
    <message>
        <location line="-1130"/>
        <source>:</source>
        <translatorcomment>--ignored colon--
--file: Arduino_it_IT.po--
Documento caricato:
Versione:</translatorcomment>
        <translation>:</translation>
    </message>
    <message>
        <location line="+150"/>
        <source>No Selection</source>
        <translatorcomment>--ignored case--
--file: photivo_it.ts--
Nessuna selezione</translatorcomment>
        <translation>Nessuna selezione</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Specific Properties</source>
        <translation>Proprietà specifiche</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Dependent Entities</source>
        <translation>Entità dipendenti</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
    <message>
        <location line="+166"/>
        <source>Index</source>
        <translation>Indice</translation>
    </message>
    <message>
        <location line="+59"/>
        <source>Remove this property from selected objects</source>
        <translation>Rimuovere questa proprietà dagli oggetti selezionati</translation>
    </message>
    <message>
        <location line="+68"/>
        <source>All</source>
        <translation>Tutto</translation>
    </message>
    <message>
        <location line="+639"/>
        <source>Widgets</source>
        <translation>Widgets</translation>
    </message>
    <message>
        <source>Add Custom Property</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Aggiungi proprietà personalizzata</translation>
    </message>
    <message>
        <source>Fit</source>
        <translatorcomment>--exact match--
--file: dia.master.it.po--
Adatta alla pagina
Primo punto di adattamento</translatorcomment>
        <translation type="obsolete">Fit</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation type="obsolete">Sotto</translation>
    </message>
    <message>
        <source>Base</source>
        <translatorcomment>--exact match--
--file: src_shell_data_translations_ktoon_it.ts--
Disegna arco tangente alla base dell&apos;oggetto
Specifica la base</translatorcomment>
        <translation type="obsolete">Base</translation>
    </message>
    <message>
        <location line="-481"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location line="+121"/>
        <source>Use auto measurement</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Utilizzare la misurazione automatica</translation>
    </message>
    <message>
        <location line="+39"/>
        <source>Yes</source>
        <translation>Si</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>No</source>
        <translation>No</translation>
    </message>
    <message>
        <location line="+320"/>
        <location line="+57"/>
        <location line="+11"/>
        <source>Property Editor</source>
        <translation>Editor delle proprietà</translation>
    </message>
    <message>
        <location filename="../PropertyEditor.ui" line="+40"/>
        <source>Selection:</source>
        <translatorcomment>--ignored colon--
--file: it3.po--</translatorcomment>
        <translation>Selezione:</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="vanished">Generale</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>General Properties</source>
        <translation>Proprietà generali</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Color:</source>
        <translation>Colore:</translation>
    </message>
    <message>
        <source>Move Selection to a New Layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Sposta la selezione ad un nuovo layer</translation>
    </message>
    <message>
        <location line="+104"/>
        <source>Linetype Scale:</source>
        <translation>Scala del tipo di linea:</translation>
    </message>
    <message>
        <location line="+49"/>
        <source>Protected:</source>
        <translation>Protetta:</translation>
    </message>
    <message>
        <location line="-143"/>
        <source>Handle:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Maniglia:</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Display Z coordinates</source>
        <translation>Visualizzare coordinate z</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Display properties of current block and current layer</source>
        <translation>Mostra proprietà del blocco corrente e livello corrente</translation>
    </message>
</context>
</TS>
